@@ -17,3 +17,8 @@ class TestGetFakeObjectDetectionDataset(unittest.TestCase):
         self.assertTrue(all(len(x[1].shape) == 2 for x in dataset))
         self.assertTrue(all(0 <= x[1] < x[3] <= 1 for _, t in dataset for x in t))
         self.assertTrue(all(0 <= x[2] < x[4] <= 1 for _, t in dataset for x in t))
+
+    def test_multiple_image_sizes(self):
+        outputs = Task(Task.Config(image_sizes=[(8, 8), (24, 24), (16, 16), (64, 2)])).execute(None)
+        image_sizes_set = set(image.size for image, targets in outputs.dataset)
+        self.assertEqual(image_sizes_set, {(8, 8), (24, 24), (16, 16), (64, 2)})
